/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package chtdecoder.datastructures;

import chtdecoder.CHTDecoder;

/**
 * A concrete implementation of the CHTCode interface.
 *
 * @author John David Ratliff
 * @version 1.2, 09/19/04
 */
class BasicCHTCode extends AbstractCHTCode {
    /**
     * Creates a new BasicCHTCode object.
     *
     * @param name The CHTCode name.
     * @param address The CHTCode address.
     * @param value The CHTCode value.
     * @param active Whether this code is active or not.
     */
    protected BasicCHTCode(String name, int address, int value,
                           boolean active) {
        setName(name);
        setAddress(address);
        setValue(value);
        setActive(active);
    }

    /**
     * Returns a String representation of this CHTCode.
     *
     * @return A String representation.
     */
    public String toString() {
        String address = CHTDecoder.zeroPad(Integer.toHexString(getAddress())
                                                   .toUpperCase(), 6);
        String value = CHTDecoder.zeroPad(Integer.toHexString(getValue())
                                                 .toUpperCase(), 2);
        String active = (isActive() ? "active  " : "inactive");

        return address + ":" + value + " is " + active + " (" + getName() +
               ")";
    }
}
